#
# spec file for package linphone
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           linphone
Version:        3.5.2
Release:        40.1
Summary:        Web Phone
License:        GPL-2.0+
Group:          Productivity/Networking/Other
Url:            http://www.linphone.org
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}-manual.tar.bz2
#FIX-FOR-UPSTREAM port linux/videodev.h to libv4l-videodev.h
Patch1:         linphone-v4l.patch
Patch2:         linphone-ffmpeg.patch
BuildRequires:  gcc-c++
%if 0%{?suse_version} >= 1130
BuildRequires:  pkgconfig(gnutls)
%else
BuildRequires:  gnutls-devel
%endif
BuildRequires:  intltool
BuildRequires:  libeXosip2-devel
BuildRequires:  libosip2-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig(libnotify)
%if 0%{?suse_version} >= 1210
BuildRequires:  libv4l-devel >= 0.8.4
%else
BuildRequires:  libv4l-devel
%endif
# lack of libsrtp-devel in SuSE, enable both of them in the future.
#BuildRequires:  libzrtpcpp-devel
BuildRequires:  alsa-devel
# future use, now in d:l:c
#BuildRequires:  libortp-devel
BuildRequires:  fdupes
BuildRequires:  libgsm-devel
BuildRequires:  libpulse-devel
BuildRequires:  libsoup-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  readline-devel
BuildRequires:  speex-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libglade-2.0)
# Video support - disabled by default due to patent issues
%bcond_with video
%if %{with video}
BuildRequires:  libffmpeg-devel
BuildRequires:  libXv-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#NoSource:       0

%description
Linphone is a Web phone with a GNOME interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%package devel
Summary:        Web Phone
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       alsa-devel
Requires:       glibc-devel
Requires:       libeXosip2-devel
Requires:       libosip2-devel
Requires:       speex-devel
Requires:       pkgconfig(glib-2.0)
%if %{with video}
Requires:       libffmpeg-devel
Requires:       libXv-devel
%endif

%description devel
Linphone is a Web phone with a GNOME interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%prep
%setup -q
%if 0%{?suse_version} >= 1210
%patch1 -p1
%patch2 -p1
%endif
translation-update-upstream
find -name "CVS" -type d -exec rm -Rfv "{}" "+"

%build
%if 0%{?suse_version} >= 1140
./autogen.sh
%endif
# needed for linphone-1.3.0:
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
	--enable-console_ui=yes \
	--enable-ipv6 \
	--enable-nonstandard-gsm \
	--enable-rsvp \
	--enable-ssl \
	--enable-alsa \
	--disable-date \
	--disable-relativeprefix \
	--disable-rpath \
	--disable-silent-rules \
	--disable-static \
	--disable-strict \
%if !%{with video}
    --disable-video \
%endif
        --enable-portaudio
# future use, now in d:l:c
#        --enable-external-ortp
# lack of srtp in SuSE. enable it in the future.
#    --enable-zrtp \

make %{?_smp_mflags}

%install
%make_install
# install manual
tar -xjC %{buildroot}%{_datadir}/gnome/help/ -f %{SOURCE1}
#cleanup
rm -fv %{buildroot}%{_includedir}/speex*
rm -fv %{buildroot}%{_datadir}/doc/speex-1.1.4/manual.pdf
# FIXME: Upstream bug: Use GNOME2-style desktop files instead of GNOME1-style.
# install desktop file
%suse_update_desktop_file -D "linphone/index.xml.html" -G "SIP Phone" %{name} Network Telephony
%find_lang %{name}
%find_lang mediastreamer
cat %{name}.lang
# delete unused man pages
rm -rf %{buildroot}%{_mandir}/cs/
# no need to package la files
rm -f %{buildroot}%{_libdir}/*.*a
cp -a ./pixmaps/linphone-3.png %{buildroot}%{_datadir}/linphone/linphone2.png
# too lazy to fix up tutorial packaging...
rm -rf %{buildroot}%{_datadir}/tutorials
# remove duplicate COPYING
rm -rf %{buildroot}%{_datadir}/%{name}/COPYING

%fdupes %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang -f mediastreamer.lang
%defattr(-,root,root)
%{_bindir}/*
%{_datadir}/sounds/linphone
%{_libdir}/*.so.*
%{_datadir}/linphone
%{_datadir}/pixmaps/linphone
%doc %{_mandir}/man1/*.*
%{_datadir}/images/nowebcamCIF.jpg
%{_datadir}/applications/linphone.desktop
%dir %{_datadir}/images
%dir %{_datadir}/gnome
%dir %{_datadir}/gnome/help
%doc NEWS AUTHORS COPYING

%files devel
%defattr(-,root,root)
%{_includedir}/linphone
%{_includedir}/ortp
%{_includedir}/mediastreamer2
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Oct 12 2012 vadimuzzz@inbox.ru
- added video support (disabled by default), to enable need to rebuild "with video"
- modify patch linphone-v4l (ffmpeg API changed)
- added linphone-ffmpeg.patch (ffmpeg API changed)
* Mon May 21 2012 jengelh@inai.de
- Use BuildRequires: pkgconfig(gnutls) instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Tue May 15 2012 i@marguerite.su
- update to version 3.5.2
  * updated oRTP to 0.20.0
  * updated mediastreamer2 to 2.8.2
  * added ZRTP media encryption
  * added SILK audio codec
- modify patch linphone-v4l.
- drop applet sub-package. since no useful data.
* Thu Nov 24 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Thu Nov 24 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Jul 24 2011 seife+obs@b1-systems.com
- update to version 3.4.3, see NEWS file for detailed changelog,
  obsoletes patches
- build / packaging improvements:
  - remove build date from binaries, use the tarball's timestamp
  - verbose build for rpmlint checking
  - add AUTHORS, NEWS, COPYING files
  - fix rpm group of devel package
  - add alsa-devel and libgsm-devel buildrequires
  - explicitly enable alsa, ssl, rsvp, ipv6
* Tue Jul 12 2011 cwh@novell.com
- fixing 11.4 build
* Thu Jul  7 2011 idonmez@novell.com
- Add linphone-v4l-2.6.38.patch: use new v4l interface
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Jan 16 2011 seife+obs@b1-systems.com
- Patch up to current git state of branch 3.3.x. Unfortunately,
  the git history is not helpful to create a changelog.
  But this fixes bnc#664808.
* Wed Dec 29 2010 aj@suse.de
- Run spec file through spec-cleaner.
- Remove build dependencies on libgnomeprintui-devel and
  libwnck-devel, they are not needed.
* Thu Nov 11 2010 coolo@novell.com
- own parent directory for gnome-panel
* Wed Aug 11 2010 ro@suse.de
- update to linphone-3.3.2
  * enhancements made to presence support (SIP/SIMPLE)
  * be nat friendly using OPTIONS request and using received,rport from
  responses.
  * use stun guessed ports even if symmetric is detected (works with freeboxes)
  * improve bitrate usage of speex codec
  * allow speex to run with vbr (variable bit rate) mode
  * add speex/32000 (ultra wide band speex codec)
  * answer empty SIP INFO requests
  * reverse order of call logs
  * optimize video display
  * manual or automatic network connectivity management (so that REGISTERs
  are only sent when network is up or refreshed when it comes back)
  * new in-call layout
  * new idle view with two buttons
  * ability to dial the number from dialpad
  * improve local IP address detection when having multiple networks (ex: VPNs)
  * use proxy's received and rport params from via in Contact header when possible
  * add an option to ask linphone to place a call, whenever an instance is already running or not:
  should be useful for starting calls from a web browser recognizing the 'sip:' uri scheme.
  * don't show ffmpeg codecs when encoder are disabled in ffmpeg library.
  * update theora default settings to match performance of 1.0 release.
  * linphone can now send large video pictures: up to SVGA, configurable via the user interface
  * automatic rescaling of the video windows to the video size of incoming stream
  * enable lookups of SRV records
  * new 'linphonecsh' program to send commands to a linphonec running as daemon using unix sockets or tcp.
  - tons of bugfixes, please see NEWS file for details
- update to version 3.0.0
  * new graphical interface based on Glade/Gtk
  * systray icon
  * STUN working for RTP
  * accurate bandwidth management (to let video occupy all remaning bandwidth)
  * new H264 plugin based on x264 (msx264)
  * automatic call hangup upon media transmission faillure
* Wed Dec  2 2009 coolo@novell.com
- update patch to fix build
* Mon May 25 2009 hvogel@suse.de
- Translations update
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translations update.
* Wed Oct 22 2008 hvogel@suse.de
- get rid of autoreconf call to make it build again
* Fri Apr 18 2008 hvogel@suse.de
- Hide online help button, we dont have an XML file to pass to
  gnome_help_display so its of no use.
* Thu Apr  3 2008 hvogel@suse.de
- update to version 2.1.1
  * Clean up commands 'nat', 'stun' and 'firewall' to be
    more intuitive
  * Upgrade to newest gettext
- fix some rpmlint warnings
- get rid of libtool archives
* Fri Jan 18 2008 mskibbe@suse.de
- portate to new libosip version
- fix typo in linphone-1.3.0.patch
* Wed Jan 16 2008 mskibbe@suse.de
- update to version 2.0.1 which
  o use new (eX)osip version
  o Clean ANSI/C vs. ANSI/C++ differences
  o fix a lot of small bugs
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Sep  4 2007 mskibbe@suse.de
- update to versin 1.7.1:
  * arts sound input/output
  * improved sound latency with alsa
  * alsa support works with dmix/dsnoop
  * fix a lot of bugs
* Tue Jun 19 2007 mskibbe@suse.de
- disable Werror
* Wed May 16 2007 ro@suse.de
- use libosip2-devel in buildrequires
* Thu Mar  8 2007 mskibbe@suse.de
- add missing directories
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Feb  8 2007 mskibbe@suse.de
- fix build problems
* Tue Jan 16 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Aug 10 2006 mskibbe@suse.de
- update to version 1.3.0 which includes
  o a lots of improvements in linphonec (see strk 's Changelogs below)
  o telephone event problem with sipomatic.
  o updated cz translation.
  o fix bugs around addressbook.
  o video support with H263-1998/RFC2429 nearly clean.
  o added timeout for incoming calls
* Sat Feb 18 2006 gekker@suse.de
- Update .desktop file for UI team
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 hvogel@suse.de
- Update to version 1.2.0
* Fri Nov 11 2005 hvogel@suse.de
- care about return values. Added
  * linphone-returnchecks.patch
* Wed Oct  5 2005 hvogel@suse.de
- update to version 1.1.0 drop
  * linphone-manual.patch
  * linphone-cs_cz.patch
  * linphone-cs_cz-fixes.patch
  * linphone-configure.patch
* Fri Sep  9 2005 hvogel@suse.de
- update cz translation
* Fri Jul  8 2005 mmj@suse.de
- fix more prototypes
* Tue Jul  5 2005 mmj@suse.de
- fix unitialized vars
- fix prototypes
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Wed Apr 20 2005 hvogel@suse.de
- fix bonobo server file to include an icon
- fix desktop file to have both Name and GenericName
- fix return values
* Tue Mar 22 2005 max@suse.de
- Update to final 1.0.0 version, which is more stable (#74253).
* Tue Mar 22 2005 sbrabec@suse.cz
- Moved applet bonobo server description to linphone-applet.
* Tue Mar 22 2005 coolo@suse.de
- split the gnome applet into an own package (#74199)
* Thu Mar 17 2005 hvogel@suse.de
- fix desktop file
* Tue Feb 15 2005 ro@suse.de
- added czech translations by Klara Cihlarova
* Thu Feb  3 2005 hvogel@suse.de
- add the manual so the manual button works
* Mon Jan 24 2005 ro@suse.de
- mark as NoSource (ffmpeg is there but unused).
* Wed Jan 19 2005 ro@suse.de
- update to 1.0.0pre6
- fixed more compiler warnings
* Sun Nov 14 2004 ro@suse.de
- fix another compile warning
* Tue Nov  9 2004 ro@suse.de
- update to 1.0.0pre4
- split patch in pieces
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed applet broken by bad libdir usage.
- Fixed libexecdir for bi-arch (#47050).
* Wed Jul 28 2004 ro@suse.de
- update to 1.0.0pre1
* Wed May 19 2004 ro@suse.de
- update to 0.12.2
- fix some compiler warnings
* Tue Feb  3 2004 ro@suse.de
- use -fno-strict-aliasing
* Wed Jan 21 2004 ro@suse.de
- update to 0.12.1
- make it build
* Mon Oct 20 2003 ro@suse.de
- don't build as root
* Sat Aug 23 2003 ro@suse.de
- update to 0.12.0
* Tue Jul 29 2003 ro@suse.de
- install it all to /opt/gnome
* Thu Jul 17 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
- Added gnome-panel to neededforbuild.
* Wed Jun 11 2003 ro@suse.de
- fix desktop file path
* Wed Jun 11 2003 ro@suse.de
- libtoolize in osipua subdirectory for proper soname
* Tue Jun 10 2003 ro@suse.de
- created package (version 0.11.0)
- use system speex library
